/*-------------------------------------------------------------------------+
| Copyright 2023 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.variability.analysis;

import static org.fortiss.tooling.kernel.utils.EcoreUtils.pickFirstInstanceOf;

import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.base.model.element.IModelElement;
import org.fortiss.tooling.base.model.element.IModelElementSpecification;
import org.fortiss.tooling.ext.variability.model.OptionalVariationPointSpecification;
import org.fortiss.variability.analysis.EMFProductLineTranslation;
import org.fortiss.variability.model.presence.PresenceCondition;
import org.fortiss.variability.model.presence.PresenceConditionTerm;

/**
 * 
 * @author bayha
 */
public class OptimizedProductLineTranslation extends EMFProductLineTranslation {

	/** {@inheritDoc} */
	@Override
	protected PresenceConditionTerm getLocalPresenceCondition(EObject model) {
		if(model instanceof IModelElement) {

			List<IModelElementSpecification> specifications =
					((IModelElement)model).getSpecifications();

			OptionalVariationPointSpecification varSpec =
					pickFirstInstanceOf(OptionalVariationPointSpecification.class, specifications);

			if(varSpec == null) {
				return null;
			}

			PresenceCondition presenceCondition = varSpec.getPresenceCondition();

			if(presenceCondition == null) {
				return null;
			}

			return presenceCondition.resolveToFeatureLiterals();
		}

		return null;
	}
}
