/*-------------------------------------------------------------------------+
| Copyright 2023 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.variability.analysis;

import java.util.Collection;
import java.util.Map;

import org.eclipse.emf.ecore.EAttribute;
import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EReference;

import com.microsoft.z3.BoolExpr;
import com.microsoft.z3.Context;
import com.microsoft.z3.EnumSort;
import com.microsoft.z3.Expr;
import com.microsoft.z3.FuncDecl;
import com.microsoft.z3.Solver;

/**
 * 
 * @author bayha
 */
public interface IProductLineTranslation {

	/**
	 * @return
	 */
	Context getContext();

	/**
	 * @param model
	 */
	void translateModel(EObject model);

	/**
	 * @param constraints
	 * @return
	 */
	Map<BoolExpr, IProductLineConstraint>
			translateConstraints(Collection<IProductLineConstraint> constraints);

	/**
	 * @return
	 */
	EObject getEObjectForExpression(Expr<?> expr);

	/**
	 * @param tracToExpr
	 * @return
	 */
	Solver createSolver(Map<BoolExpr, BoolExpr> tracToExpr);

	/**
	 * @param cls
	 * @return
	 */
	FuncDecl getSelectionFunction(EClass cls);

	/**
	 * @param cls
	 * @return
	 */
	Expr<?> getNullElement(EClass cls);

	/**
	 * @param excludedClasses
	 */
	@Deprecated
	void addExcludedClasses(Collection<EClass> excludedClasses);

	/**
	 * @param ec
	 * @return
	 */
	EnumSort getDatatype(EClass ec);

	/**
	 * @param cVarType
	 * @param string
	 * @return
	 */
	FuncDecl getAttributeReferenceFunctionDeclaration(EClass cVarType, String string);

	public void setTranslatedEClasses(Collection<EClass> clss);

	public void setTranslatedEReferences(Collection<EReference> refs);

	public void setTranslatedEAttributes(Collection<EAttribute> atts);

}
